@@ -343,6 +343,16 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             ):
                 connection_headers["X-Access-Token"] = envd_access_token
 
+        connection_config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+            headers=connection_headers,
+            proxy=proxy,
+        )
+
+        if "brd" in sandbox_id.lower():
             # Get SSH connection details
             ssh_info = await SandboxApi._get_ssh(
                 sandbox_id=sandbox_id,
@@ -371,29 +381,29 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
                 debug=debug,
                 proxy=proxy,
             )
-        connection_config = ConnectionConfig(
-            api_key=api_key,
-            domain=domain,
-            debug=debug,
-            request_timeout=request_timeout,
-            headers=connection_headers,
-            proxy=proxy,
-        )
+            return cls(
+                sandbox_id=sandbox_id,
+                envd_version=envd_version,
+                envd_access_token=envd_access_token,
+                connection_config=connection_config,
+                ssh_host=ssh_host,
+                ssh_port=ssh_port,
+                ssh_username=ssh_username,
+                ssh_password=ssh_password,
+                adb_auth_command=adb_info.adb_auth_command,
+                adb_auth_password=adb_info.auth_password,
+                adb_connect_command=adb_info.connect_command,
+                adb_forwarder_command=adb_info.forwarder_command
+            )
+        else:
+            return cls(
+                sandbox_id=sandbox_id,
+                envd_version=envd_version,
+                envd_access_token=envd_access_token,
+                connection_config=connection_config,
+            )
+
 
-        return cls(
-            sandbox_id=sandbox_id,
-            envd_version=envd_version,
-            envd_access_token=envd_access_token,
-            connection_config=connection_config,
-            ssh_host=ssh_host,
-            ssh_port=ssh_port,
-            ssh_username=ssh_username,
-            ssh_password=ssh_password,
-            adb_auth_command=adb_info.adb_auth_command,
-            adb_auth_password=adb_info.auth_password,
-            adb_connect_command=adb_info.connect_command,
-            adb_forwarder_command=adb_info.forwarder_command
-        )
 
     @classmethod
     async def connect(
